@@ -27,16 +27,13 @@ from . import print
 
 if __name__ in ("__main__", "psprint.__main__"):
     print()
-    print("usage:",
-          pref='err', pad=True, short=False)
-    print("Use me as an imported module",
-          pref='info', pad=True, short=False)
+    print("usage:", mark='err', pad=True, short=False)
+    print("Use me as an imported module", mark='info', pad=True, short=False)
     print("from psprint import PRINT as print",
-          pref='act', pad=True, short=False)
+          mark='act', pad=True, short=False)
     print("Styles may be edited by importing the InfoPrint class",
-          pref='list', pad=True, short=False)
+          mark='list', pad=True, short=False)
     print("Or by editing its DEFAULT_PRINT instance",
           pad=True, short=False)
-    print("Bye",
-          pref='bug', pad=True, short=False)
+    print("Bye", mark='bug', pad=True, short=False)
     print()
